@@ -1,23 +1,33 @@
 package WebAPI::DBIC::Resource::Role::Set;
-$WebAPI::DBIC::Resource::Role::Set::VERSION = '0.001008';
+$WebAPI::DBIC::Resource::Role::Set::VERSION = '0.001009';
 
 use Moo::Role;
 
 
 requires 'encode_json';
-requires 'render_set_as_plain';
-requires 'render_set_as_hal';
+requires 'render_item_as_plain_hash';
 
 
+has content_types_provided => (
+    is => 'lazy',
+);
+
+sub _build_content_types_provided {
+    return [ { 'application/json' => 'to_plain_json'} ]
+}
+
+sub to_plain_json { return $_[0]->encode_json($_[0]->render_set_as_plain($_[0]->set)) }
+
 sub allowed_methods { return [ qw(GET HEAD) ] }
 
-sub content_types_provided { return [
-    {'application/hal+json' => 'to_hal_json'},
-    {'application/json'     => 'to_plain_json'},
-] } 
+# Avoid complaints about $set:
+## no critic (NamingConventions::ProhibitAmbiguousNames)
 
-sub to_plain_json { return $_[0]->encode_json($_[0]->render_set_as_plain($_[0]->set)) }
-sub to_hal_json   { return $_[0]->encode_json($_[0]->render_set_as_hal(  $_[0]->set)) }
+sub render_set_as_plain {
+    my ($self, $set) = @_;
+    my $set_data = [ map { $self->render_item_as_plain_hash($_) } $set->all ];
+    return $set_data;
+}
 
 1;
 
@@ -33,14 +43,14 @@ WebAPI::DBIC::Resource::Role::Set
 
 =head1 VERSION
 
-version 0.001008
+version 0.001009
 
 =head1 DESCRIPTION
 
 Handles GET and HEAD requests for requests representing set resources, e.g.
 the rows of a database table.
 
-Supports the C<application/hal+json> and C<application/json> content types.
+Supports the C<application/json> content type.
 
 =head1 NAME
 
